@@ -18,7 +18,7 @@ pub(crate) fn footer(meta: &Node) -> Result<String, Error> {
     if !link.is_empty() {
         doc += &format!("<a href=\"{}\">", link);
     }
-    let (src, size) = sized_block(&footer)?;
+    let (src, size) = sized_block(footer)?;
     doc += &format!("<img{}{}/>", src, size);
     let label = footer.get_default("label", "", Node::as_str)?;
     if !label.is_empty() {
