@@ -1,5 +1,6 @@
 pub(crate) trait WrapString {
     fn wrap(self, prefix: &str, suffix: &str) -> String;
+    fn escape(self) -> String;
 }
 
 impl<S: AsRef<str>> WrapString for S {
@@ -11,4 +12,9 @@ impl<S: AsRef<str>> WrapString for S {
             format!("{}{}{}", prefix, s, suffix)
         }
     }
+
+    fn escape(self) -> String {
+        let s = self.as_ref();
+        s.replace('\n', "\\n").replace('"', "\\\"")
+    }
 }
